@@ -43,6 +43,8 @@
 #include <AkonadiCore/agenttype.h>
 #include <AkonadiCore/agentmanager.h>
 #include <AkonadiCore/agentinstancecreatejob.h>
+#include <AkonadiCore/CollectionFetchJob>
+
 
 #include <QMetaMethod>
 #include <QDir>
@@ -158,6 +160,114 @@ void ImportMailJob::storeMailArchiveResource(const KArchiveDirectory *dir, const
     }
 }
 
+void ImportMailJob::importMailTransport(const QString &tempDirName)
+{
+    KSharedConfig::Ptr transportConfig = KSharedConfig::openConfig(tempDirName + QLatin1Char('/') + QLatin1String("mailtransports"));
+
+    int defaultTransport = -1;
+    if (transportConfig->hasGroup(QStringLiteral("General"))) {
+        KConfigGroup group = transportConfig->group(QStringLiteral("General"));
+        defaultTransport = group.readEntry(QStringLiteral("default-transport"), -1);
+    }
+
+    const QStringList transportList = transportConfig->groupList().filter(QRegularExpression(QStringLiteral("Transport \\d+")));
+    for (const QString &transport : transportList) {
+        KConfigGroup group = transportConfig->group(transport);
+        const int transportId = group.readEntry(QStringLiteral("id"), -1);
+        if (transportId == -1) {
+            qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Mail Transport is incorrect. Missing Id";
+            continue;
+        }
+        const QString identifierStr(QStringLiteral("identifier"));
+        if (group.hasKey(identifierStr)) {
+            const QString identifierValue = group.readEntry(identifierStr);
+            if (!identifierValue.isEmpty()) {
+                if (identifierValue == QLatin1String("sendmail") || identifierValue == QLatin1String("akonadi_ewsmta_resource")) {
+                    MailTransport::Transport *mt = MailTransport::TransportManager::self()->createTransport();
+                    mt->setName(group.readEntry(QStringLiteral("name")));
+                    const QString hostStr(QStringLiteral("host"));
+                    if (group.hasKey(hostStr)) {
+                        mt->setHost(group.readEntry(hostStr));
+                    }
+                    mt->setIdentifier(identifierValue);
+                    addMailTransport(mt, defaultTransport, transportId);
+                } else {
+                    qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Unknown identifier type " << identifierValue;
+                }
+            } else {
+                qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "identifier value is empty";
+            }
+        } else {
+            MailTransport::Transport *mt = MailTransport::TransportManager::self()->createTransport();
+            mt->setName(group.readEntry(QStringLiteral("name")));
+            const QString hostStr(QStringLiteral("host"));
+            if (group.hasKey(hostStr)) {
+                mt->setHost(group.readEntry(hostStr));
+            }
+            const QString portStr(QStringLiteral("port"));
+            if (group.hasKey(portStr)) {
+                mt->setPort(group.readEntry(portStr, -1));
+            }
+            const QString userNameStr(QStringLiteral("user"));
+            if (group.hasKey(userNameStr)) {
+                mt->setUserName(group.readEntry(userNameStr));
+            }
+            const QString precommandStr(QStringLiteral("precommand"));
+            if (group.hasKey(precommandStr)) {
+                mt->setPrecommand(group.readEntry(precommandStr));
+            }
+            const QString requiresAuthenticationStr(QStringLiteral("auth"));
+            if (group.hasKey(requiresAuthenticationStr)) {
+                mt->setRequiresAuthentication(group.readEntry(requiresAuthenticationStr, false));
+            }
+            const QString specifyHostnameStr(QStringLiteral("specifyHostname"));
+            if (group.hasKey(specifyHostnameStr)) {
+                mt->setSpecifyHostname(group.readEntry(specifyHostnameStr, false));
+            }
+            const QString localHostnameStr(QStringLiteral("localHostname"));
+            if (group.hasKey(localHostnameStr)) {
+                mt->setLocalHostname(group.readEntry(localHostnameStr));
+            }
+            const QString specifySenderOverwriteAddressStr(QStringLiteral("specifySenderOverwriteAddress"));
+            if (group.hasKey(specifySenderOverwriteAddressStr)) {
+                mt->setSpecifySenderOverwriteAddress(group.readEntry(specifySenderOverwriteAddressStr, false));
+            }
+            const QString storePasswordStr(QStringLiteral("storepass"));
+            if (group.hasKey(storePasswordStr)) {
+                mt->setStorePassword(group.readEntry(storePasswordStr, false));
+            }
+            const QString senderOverwriteAddressStr(QStringLiteral("senderOverwriteAddress"));
+            if (group.hasKey(senderOverwriteAddressStr)) {
+                mt->setSenderOverwriteAddress(group.readEntry(senderOverwriteAddressStr));
+            }
+            const QString encryptionStr(QStringLiteral("encryption"));
+            if (group.hasKey(encryptionStr)) {
+                const QString encryptionType = group.readEntry(encryptionStr, QString());
+                if (!encryptionType.isEmpty()) {
+                    if (encryptionType == QLatin1String("TLS")) {
+                        mt->setEncryption(static_cast<int>(MailTransport::TransportBase::EnumEncryption::TLS));
+                    } else if (encryptionType == QLatin1String("SSL")) {
+                        mt->setEncryption(static_cast<int>(MailTransport::TransportBase::EnumEncryption::SSL));
+                    } else if (encryptionType == QLatin1String("None")) {
+                        mt->setEncryption(static_cast<int>(MailTransport::TransportBase::EnumEncryption::None));
+                    } else {
+                        qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Unknown encryption type " << encryptionType;
+                    }
+                } else {
+                    qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Encryption type is empty. It's a bug";
+                }
+                mt->setEncryption(group.readEntry(encryptionStr, 1)); //TODO verify
+            }
+            const QString authenticationTypeStr(QStringLiteral("authtype"));
+            if (group.hasKey(authenticationTypeStr)) {
+                mt->setAuthenticationType(group.readEntry(authenticationTypeStr, 1)); //TODO verify
+            }
+            addMailTransport(mt, defaultTransport, transportId);
+        }
+    }
+
+}
+
 void ImportMailJob::restoreTransports()
 {
     setProgressDialogLabel(i18n("Restore transports..."));
@@ -173,109 +283,7 @@ void ImportMailJob::restoreTransports()
             const KArchiveFile *fileTransport = static_cast<const KArchiveFile *>(transport);
 
             fileTransport->copyTo(mTempDirName);
-            KSharedConfig::Ptr transportConfig = KSharedConfig::openConfig(mTempDirName + QLatin1Char('/') + QLatin1String("mailtransports"));
-
-            int defaultTransport = -1;
-            if (transportConfig->hasGroup(QStringLiteral("General"))) {
-                KConfigGroup group = transportConfig->group(QStringLiteral("General"));
-                defaultTransport = group.readEntry(QStringLiteral("default-transport"), -1);
-            }
-
-            const QStringList transportList = transportConfig->groupList().filter(QRegularExpression(QStringLiteral("Transport \\d+")));
-            for (const QString &transport : transportList) {
-                KConfigGroup group = transportConfig->group(transport);
-                const int transportId = group.readEntry(QStringLiteral("id"), -1);
-                if (transportId == -1) {
-                    qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Mail Transport is incorrect. Missing Id";
-                    continue;
-                }
-                const QString identifierStr(QStringLiteral("identifier"));
-                if (group.hasKey(identifierStr)) {
-                    const QString identifierValue = group.readEntry(identifierStr);
-                    if (!identifierValue.isEmpty()) {
-                        if (identifierValue == QLatin1String("sendmail") || identifierValue == QLatin1String("akonadi_ewsmta_resource")) {
-                            MailTransport::Transport *mt = MailTransport::TransportManager::self()->createTransport();
-                            mt->setName(group.readEntry(QStringLiteral("name")));
-                            const QString hostStr(QStringLiteral("host"));
-                            if (group.hasKey(hostStr)) {
-                                mt->setHost(group.readEntry(hostStr));
-                            }
-                            mt->setIdentifier(identifierValue);
-                            addMailTransport(mt, defaultTransport, transportId);
-                        } else {
-                            qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Unknown identifier type " << identifierValue;
-                        }
-                    } else {
-                        qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "identifier value is empty";
-                    }
-                } else {
-                    MailTransport::Transport *mt = MailTransport::TransportManager::self()->createTransport();
-                    mt->setName(group.readEntry(QStringLiteral("name")));
-                    const QString hostStr(QStringLiteral("host"));
-                    if (group.hasKey(hostStr)) {
-                        mt->setHost(group.readEntry(hostStr));
-                    }
-                    const QString portStr(QStringLiteral("port"));
-                    if (group.hasKey(portStr)) {
-                        mt->setPort(group.readEntry(portStr, -1));
-                    }
-                    const QString userNameStr(QStringLiteral("user"));
-                    if (group.hasKey(userNameStr)) {
-                        mt->setUserName(group.readEntry(userNameStr));
-                    }
-                    const QString precommandStr(QStringLiteral("precommand"));
-                    if (group.hasKey(precommandStr)) {
-                        mt->setPrecommand(group.readEntry(precommandStr));
-                    }
-                    const QString requiresAuthenticationStr(QStringLiteral("auth"));
-                    if (group.hasKey(requiresAuthenticationStr)) {
-                        mt->setRequiresAuthentication(group.readEntry(requiresAuthenticationStr, false));
-                    }
-                    const QString specifyHostnameStr(QStringLiteral("specifyHostname"));
-                    if (group.hasKey(specifyHostnameStr)) {
-                        mt->setSpecifyHostname(group.readEntry(specifyHostnameStr, false));
-                    }
-                    const QString localHostnameStr(QStringLiteral("localHostname"));
-                    if (group.hasKey(localHostnameStr)) {
-                        mt->setLocalHostname(group.readEntry(localHostnameStr));
-                    }
-                    const QString specifySenderOverwriteAddressStr(QStringLiteral("specifySenderOverwriteAddress"));
-                    if (group.hasKey(specifySenderOverwriteAddressStr)) {
-                        mt->setSpecifySenderOverwriteAddress(group.readEntry(specifySenderOverwriteAddressStr, false));
-                    }
-                    const QString storePasswordStr(QStringLiteral("storepass"));
-                    if (group.hasKey(storePasswordStr)) {
-                        mt->setStorePassword(group.readEntry(storePasswordStr, false));
-                    }
-                    const QString senderOverwriteAddressStr(QStringLiteral("senderOverwriteAddress"));
-                    if (group.hasKey(senderOverwriteAddressStr)) {
-                        mt->setSenderOverwriteAddress(group.readEntry(senderOverwriteAddressStr));
-                    }
-                    const QString encryptionStr(QStringLiteral("encryption"));
-                    if (group.hasKey(encryptionStr)) {
-                        const QString encryptionType = group.readEntry(encryptionStr, QString());
-                        if (!encryptionType.isEmpty()) {
-                            if (encryptionType == QLatin1String("TLS")) {
-                                mt->setEncryption(static_cast<int>(MailTransport::TransportBase::EnumEncryption::TLS));
-                            } else if (encryptionType == QLatin1String("SSL")) {
-                                mt->setEncryption(static_cast<int>(MailTransport::TransportBase::EnumEncryption::SSL));
-                            } else if (encryptionType == QLatin1String("None")) {
-                                mt->setEncryption(static_cast<int>(MailTransport::TransportBase::EnumEncryption::None));
-                            } else {
-                                qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Unknown encryption type " << encryptionType;
-                            }
-                        } else {
-                            qCWarning(PIMSETTINGEXPORTERCORE_LOG) << "Encryption type is empty. It's a bug";
-                        }
-                        mt->setEncryption(group.readEntry(encryptionStr, 1)); //TODO verify
-                    }
-                    const QString authenticationTypeStr(QStringLiteral("authtype"));
-                    if (group.hasKey(authenticationTypeStr)) {
-                        mt->setAuthenticationType(group.readEntry(authenticationTypeStr, 1)); //TODO verify
-                    }
-                    addMailTransport(mt, defaultTransport, transportId);
-                }
-            }
+            importMailTransport(mTempDirName);
             Q_EMIT info(i18n("Transports restored."));
         } else {
             Q_EMIT error(i18n("Failed to restore transports file."));
@@ -912,6 +920,19 @@ void ImportMailJob::importSimpleFilesInDirectory(const QString &relativePath)
     }
 }
 
+void ImportMailJob::registerSpecialCollection(Akonadi::SpecialMailCollections::Type type, qint64 colId)
+{
+    auto fetch = new Akonadi::CollectionFetchJob(Akonadi::Collection(colId), Akonadi::CollectionFetchJob::Base, this);
+    connect(fetch, &Akonadi::CollectionFetchJob::collectionsReceived,
+            this, [this, type](const Akonadi::Collection::List &cols) {
+                if (cols.count() != 1) {
+                    return;
+                }
+                Akonadi::SpecialMailCollections::self()->registerCollection(type, cols.first());
+            });
+}
+
+
 void ImportMailJob::restoreIdentity()
 {
     increaseProgressDialog();
@@ -940,13 +961,16 @@ void ImportMailJob::restoreIdentity()
                     group.deleteEntry(uidStr);
                 }
                 const QString fcc(QStringLiteral("Fcc"));
-                convertRealPathToCollection(group, fcc);
+                qint64 fccId = convertRealPathToCollection(group, fcc);
+                registerSpecialCollection(Akonadi::SpecialMailCollections::SentMail, fccId);
 
                 const QString draft = QStringLiteral("Drafts");
-                convertRealPathToCollection(group, draft);
+                qint64 draftId = convertRealPathToCollection(group, draft);
+                registerSpecialCollection(Akonadi::SpecialMailCollections::Drafts, draftId);
 
                 const QString templates = QStringLiteral("Templates");
-                convertRealPathToCollection(group, templates);
+                qint64 templateId = convertRealPathToCollection(group, templates);
+                registerSpecialCollection(Akonadi::SpecialMailCollections::Templates, templateId);
 
                 if (oldUid != -1) {
                     const QString vcard = QStringLiteral("VCardFile");
