@@ -21,7 +21,9 @@
 #define ImportMailJob_H
 
 #include "abstractimportexportjob.h"
+#include "pimsettingexportercore_private_export.h"
 #include <AkonadiCore/Collection>
+#include <Akonadi/KMime/SpecialMailCollections>
 #include <QStringList>
 #include <QHash>
 #include <KArchive>
@@ -31,7 +33,7 @@ class ArchiveStorage;
 namespace MailTransport {
 class Transport;
 }
-class ImportMailJob : public AbstractImportExportJob
+class PIMSETTINGEXPORTER_TESTS_EXPORT ImportMailJob : public AbstractImportExportJob
 {
     Q_OBJECT
 public:
@@ -40,10 +42,13 @@ public:
 
     void start() override;
 
+    //For debugging
+    void importMailTransport(const QString &tempDirName);
 protected:
     void slotNextStep() override;
 
 private:
+    void registerSpecialCollection(Akonadi::SpecialMailCollections::Type type, qint64 colId);
     void restoreTransports();
     void restoreResources();
     void restoreMails();
@@ -66,7 +71,7 @@ private:
     void addMailTransport(MailTransport::Transport *mt, int defaultTransport, int transportId);
     QString uniqueIdentityName(const QString &name);
 
-    QHash<uint, uint> mHashIdentity;
+    QHash<int, uint> mHashIdentity;
     QHash<int, int> mHashTransport;
     QHash<QString, QString> mHashResources;
     QStringList mFileList;
