@@ -21,9 +21,10 @@
 #define IMPORTNOTESJOB_H
 
 #include "abstractimportexportjob.h"
+#include "pimsettingexportercore_private_export.h"
 class ArchiveStorage;
 
-class ImportNotesJob : public AbstractImportExportJob
+class PIMSETTINGEXPORTER_TESTS_EXPORT ImportNotesJob : public AbstractImportExportJob
 {
     Q_OBJECT
 public:
