@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class PimSettingBackupThread : public QThread
     Q_OBJECT
 public:
     explicit PimSettingBackupThread(KZip *zip, const QString &url, const QString &archivePath, const QString &archivename, QObject *parent = nullptr);
-    ~PimSettingBackupThread();
+    ~PimSettingBackupThread() override;
 
 Q_SIGNALS:
     void error(const QString &str);
